import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_apigatewayv2._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_cognito._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_elasticloadbalancing._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_globalaccelerator._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_route53._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.core._jsii
import aws_cdk.region_info._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-route53-targets",
    "1.95.0",
    __name__[0:-6],
    "aws-route53-targets@1.95.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
